"""AKTools 是 AKShare 的 HTTP server 工具, 主要用于把 AKShare 的数据接口部署到本地从而通过 HTTP 访问"""

"""
Changelog

0.0.1:for test
0.0.2:FastAPI test
0.0.3:FastAPI deployment test
0.0.4:add docs
0.0.5:add automate package management
0.0.6:add automate package management success
0.0.7:add automate release test
0.0.8:add automate release test again
0.0.9:add automate success
0.0.10:fix: rename workflows
0.0.11:fix: README.md
0.0.12:fix: README.md
0.0.13:fix: test pull_request
0.0.14:fix: test master push tag
0.0.15:fix: update PYPI info
0.0.16:fix: update PYPI info
0.0.17:fix: update PYPI info
0.0.18:add: add params to interface
0.0.19:fix: rename file name
0.0.20:fix: rename api name
0.0.21:fix: rename api name
0.0.22:fix: fix core module
0.0.23:fix: fix core module
0.0.24:fix: fix chinese character params in api
0.0.25:test: test
0.0.26:test: test
0.0.27:test: test
0.0.28:test: test
0.0.29:test: test
0.0.30:add: add cmd arg parser
"""

__title__ = "AKTools"
__version__ = "0.0.30"
__author__ = "Albert King"
